@@ -1,6 +1,6 @@
 import click
 from womg_core import womgc
-from womg.topic.lda import LDA
+from womg.topic.lda import LDA_extended
 from womg_core.utils.distributions import set_seed
 #from womg.utils.saver import TxtSaver
 
@@ -23,10 +23,6 @@ def womg_main(graph=None,
               path_out=None,
               seed=None,
               progress_bar=True,
-              save_all=False,
-              save_int=False,
-              save_infl=False,
-              save_keyw=False,
               single_activator=False):
     '''
 
@@ -99,22 +95,10 @@ def womg_main(graph=None,
         boolean for specifying the progress bar related to the environment
         if True progress_bar=tqdm_notebook -> Jupyter progress_bar;
         if False progress_bar=tqdm. Default False
-
-    save_int : bool
-        if True WoMG saves the interests vector for each node
-
-    save_infl : bool
-        if True WoMG saves the influence vector for each node
-
-    save_keyw : bool
-        if True WoMG saves the keywords in a bow format for each document
-
-    save_all : bool
-        save all non-optional outputs
     '''
 
     set_seed(seed)
-    topic_model = LDA(numb_topics=numb_topics,
+    topic_model = LDA_extended(numb_topics=numb_topics,
                       numb_docs=numb_docs,
                       docs_path=docs_path,
                       items_descr=items_descr,
@@ -136,11 +120,7 @@ def womg_main(graph=None,
                  virality_resistance=virality_resistance,
                  numb_steps=numb_steps,
                  progress_bar=progress_bar,
-                 path_out=path_out,
-                 save_all=save_all,
-                 save_int=save_int,
-                 save_infl=save_infl,
-                 save_keyw=save_keyw)
+                 path_out=path_out)
 
     return prop
 
@@ -208,9 +188,6 @@ def womg_main(graph=None,
 @click.option('--save_keyw', is_flag=True,
                     help='if True WoMG saves the keywords in a bow format for each document',
                     default=False)
-@click.option('--save_all', is_flag=True,
-                    help='if True WoMG saves all non-optional outputs',
-                    default=False)
 @click.option('--single_activator', is_flag=True,
                     help='if True we have at most one activator per item, else god node will activate all nodes beyond threshold',
                     default=False)
@@ -222,13 +199,13 @@ def main_cli(graph,
              virality_resistance,
              interests,
              int_mode,
-             weighted, directed, docs_folder,
+             weighted, directed,
+             docs_folder,
              gn_strength,
              infl_strength,
              output, seed,
              progress_bar,
              single_activator,
-             save_all,
              save_int,
              save_infl,
              save_keyw):
@@ -242,27 +219,30 @@ def main_cli(graph,
     Please check the github page for more details.
 
     '''
-    womg_main(graph=graph,
-              docs_path=docs_folder,
-              items_descr=items_descr,
-              numb_topics=topics, numb_docs=docs,
-              numb_steps=steps, homophily=homophily,
-              gn_strength=gn_strength,
-              infl_strength=infl_strength,
-              virality_exp=virality_exp,
-              virality_resistance=virality_resistance,
-              interests=interests,
-              int_mode=int_mode,
-              weighted=weighted, directed=directed,
-              path_out=output,
-              seed=seed,
-              progress_bar=progress_bar,
-              save_all=save_all,
-              save_int=save_int,
-              save_infl=save_infl,
-              save_keyw=save_keyw,
-              single_activator=single_activator)
+    prop = womg_main(graph=graph,
+                     docs_path=docs_folder,
+                     items_descr=items_descr,
+                     numb_topics=topics, numb_docs=docs,
+                     numb_steps=steps, homophily=homophily,
+                     gn_strength=gn_strength,
+                     infl_strength=infl_strength,
+                     virality_exp=virality_exp,
+                     virality_resistance=virality_resistance,
+                     interests=interests,
+                     int_mode=int_mode,
+                     weighted=weighted, directed=directed,
+                     path_out=output,
+                     seed=seed,
+                     progress_bar=progress_bar,
+                     single_activator=single_activator)
 
+    save(network_model=prop.network_model,
+         topic_model=prop.topic_model,
+         diffusion_model=prop.diffusion_model,
+         path=output,
+         save_int=save_int,
+         save_infl=save_infl,
+         save_keyw=save_keyw)
 
 if __name__ == '__main__':
     main_cli()
